.. toctree::
    :caption: Application developer guide
    :maxdepth: 1

    devel/starting
    devel/integration
    devel/gettext
    devel/sphinx
    devel/html
    devel/alerts
    devel/community
    devel/translations
    devel/review
    devel/share
    devel/reporting
